@@ -149,60 +149,28 @@ class OMFITmhdin(OMFITnamelist):
                     if item not in self['IN3'] and item not in ['AE', 'AE2']:
                         self['IN3'][item] = np.array([])
 
-            # vessel and PFs are separated
-            if len(self['IN3']['RVS']):
-                self['FC'] = np.array(
-                    [
-                        self['IN3']['RF'],
-                        self['IN3']['ZF'],
-                        self['IN3']['WF'],
-                        self['IN3']['HF'],
-                        self['IN3']['AF'],
-                        self['IN3']['AF2'] + (self['IN3']['AF2'] == 0) * 90,
-                    ]
-                ).T
-                self['OH'] = np.array(
-                    [self['IN3']['RE'], self['IN3']['ZE'], self['IN3']['WE'], self['IN3']['HE'], self['IN3']['HE'] * 0 + 1]
-                ).T
-                self['VESSEL'] = np.array(
-                    [
-                        self['IN3']['RVS'],
-                        self['IN3']['ZVS'],
-                        self['IN3']['WVS'],
-                        self['IN3']['HVS'],
-                        self['IN3']['AVS'],
-                        self['IN3']['AVS2'] + (self['IN3']['AVS2'] == 0) * 90,
-                    ]
-                ).T
-
-            # vessel as PFs
-            else:
-                tmp = np.unique(self['IN3']['FCID'] - 1)
-                pf_ids = tmp[: -len(self['IN3']['VSNAME'])]
-                vessel_ids = tmp[-len(self['IN3']['VSNAME']) :]
-                split = int(np.max(pf_ids)) - 1
-                PF = np.array(
-                    [
-                        self['IN3']['RF'],
-                        self['IN3']['ZF'],
-                        self['IN3']['WF'],
-                        self['IN3']['HF'],
-                        self['IN3']['AF'],
-                        (self['IN3']['AF2'] + (self['IN3']['AF2'] == 0) * 90),
-                    ]
-                ).T
-                self['FC'] = PF[:split, :]
-                self['OH'] = np.array(
-                    [self['IN3']['RE'], self['IN3']['ZE'], self['IN3']['WE'], self['IN3']['HE'], self['IN3']['HE'] * 0 + 1]
-                ).T
-                self['VESSEL'] = PF[split:, :]
-
-                self['IN3']['RVS'] = self['VESSEL'][:, 0]
-                self['IN3']['ZVS'] = self['VESSEL'][:, 1]
-                self['IN3']['WVS'] = self['VESSEL'][:, 2]
-                self['IN3']['HVS'] = self['VESSEL'][:, 3]
-                self['IN3']['AVS'] = self['VESSEL'][:, 4]
-                self['IN3']['AVS2'] = self['VESSEL'][:, 5]
+            # populate aggregated arrays
+            self['FC'] = np.array(
+                [
+                    self['IN3']['RF'],
+                    self['IN3']['ZF'],
+                    self['IN3']['WF'],
+                    self['IN3']['HF'],
+                    self['IN3']['AF'],
+                    self['IN3']['AF2'] + (self['IN3']['AF2'] == 0) * 90,
+                ]
+            ).T
+            self['OH'] = np.array([self['IN3']['RE'], self['IN3']['ZE'], self['IN3']['WE'], self['IN3']['HE'], self['IN3']['HE'] * 0 + 1]).T
+            self['VESSEL'] = np.array(
+                [
+                    self['IN3']['RVS'],
+                    self['IN3']['ZVS'],
+                    self['IN3']['WVS'],
+                    self['IN3']['HVS'],
+                    self['IN3']['AVS'],
+                    self['IN3']['AVS2'] + (self['IN3']['AVS2'] == 0) * 90,
+                ]
+            ).T
 
     @dynaSave
     def save(self, *args, **kw):
@@ -258,7 +226,7 @@ class OMFITmhdin(OMFITnamelist):
         finally:
             # restore angles
             for item in angle2_special:
-                self['IN3'][item] = angle2_special
+                self['IN3'][item] = angle2_special[item]
             # restore non-namelist components
             for item in mhdin_special:
                 if item in tmp:
@@ -827,6 +795,100 @@ class OMFITmhdin(OMFITnamelist):
 
         return self
 
+    def to_omas(self, ods=None, update=['pf_active', 'magnetics']):
+        """
+        Transfers data in EFIT mhdin.dat format to ODS
+
+        WARNING: only rudimentary identifies are assigned for pf_active
+        You should assign your own identifiers and only rely on this function to assign numerical geometry data.
+
+        :param ods: ODS instance
+            Data will be added in-place
+
+        :param update: IDS to populate
+            ['pf_active', 'magnetics']
+
+        :return: ODS instance
+        """
+
+        from omas.omas_plot import geo_type_lookup
+        from omas import omas_environment, ODS
+
+        if ods is None:
+            ods = ODS()
+
+        # pf_active
+        if 'pf_active' in update:
+            coil_data = self['FC']
+            turns = self['IN3']['FCTURN']
+            elements_id = (self['IN3']['FCID'] - 1).astype(int)
+            rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
+            outline_code = geo_type_lookup('outline', 'pf_active', ods.imas_version, reverse=True)
+            for i in range(len(coil_data)):
+                c = elements_id[i]
+                e = sum(elements_id[:i] == c)
+                ods['pf_active.coil'][c]['name'] = f'PF{c}'
+                ods['pf_active.coil'][c]['identifier'] = f'PF{c}'
+                ods['pf_active.coil'][c]['element'][e]['name'] = f'PF{c}_{e}'
+                ods['pf_active.coil'][c]['element'][e]['identifier'] = f'PF{c}_{e}'
+                ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
+                if coil_data[i, 4] == 0 and coil_data[i, 5] == 0:
+                    rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
+                    rect['r'] = coil_data[i, 0]
+                    rect['z'] = coil_data[i, 1]
+                    rect['width'] = coil_data[i, 2]  # Or width in R
+                    rect['height'] = coil_data[i, 3]  # Or height in Z
+                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = rect_code
+                else:
+                    outline = ods['pf_active.coil'][c]['element'][e]['geometry.outline']
+                    fdat = coil_data[i]
+                    fdat[4] = -coil_data[i, 4] * np.pi / 180.0
+                    fdat[5] = -(coil_data[i, 5] * np.pi / 180.0 if coil_data[i, 5] != 0 else np.pi / 2)
+                    outline['r'] = [
+                        fdat[0] - fdat[2] / 2.0 - fdat[3] / 2.0 * np.tan((np.pi / 2.0 + fdat[5])),
+                        fdat[0] - fdat[2] / 2.0 + fdat[3] / 2.0 * np.tan((np.pi / 2.0 + fdat[5])),
+                        fdat[0] + fdat[2] / 2.0 + fdat[3] / 2.0 * np.tan((np.pi / 2.0 + fdat[5])),
+                        fdat[0] + fdat[2] / 2.0 - fdat[3] / 2.0 * np.tan((np.pi / 2.0 + fdat[5])),
+                    ]
+                    outline['z'] = [
+                        fdat[1] - fdat[3] / 2.0 - fdat[2] / 2.0 * np.tan(-fdat[4]),
+                        fdat[1] + fdat[3] / 2.0 - fdat[2] / 2.0 * np.tan(-fdat[4]),
+                        fdat[1] + fdat[3] / 2.0 + fdat[2] / 2.0 * np.tan(-fdat[4]),
+                        fdat[1] - fdat[3] / 2.0 + fdat[2] / 2.0 * np.tan(-fdat[4]),
+                    ]
+                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = outline_code
+
+        # magnetics
+        if 'magnetics' in update:
+            R_flux_loop = self['IN3']['RSI']
+            Z_flux_loop = self['IN3']['ZSI']
+            name_flux_loop = self['IN3']['LPNAME']
+            R_magnetic = self['IN3']['XMP2']
+            Z_magnetic = self['IN3']['YMP2']
+            A_magnetic = self['IN3']['AMP2']
+            S_magnetic = self['IN3']['SMP2']
+            name_magnetic = self['IN3']['MPNAM2']
+            with omas_environment(ods, cocosio=1):
+                for k, (r, z, name) in enumerate(zip(R_flux_loop, Z_flux_loop, name_flux_loop)):
+                    ods[f'magnetics.flux_loop.{k}.name'] = name
+                    ods[f'magnetics.flux_loop.{k}.identifier'] = 'F_' + name
+                    ods[f'magnetics.flux_loop.{k}.position[0].r'] = r
+                    ods[f'magnetics.flux_loop.{k}.position[0].z'] = z
+                    ods[f'magnetics.flux_loop.{k}.type.index'] = 1
+
+                for k, (r, z, a, s, name) in enumerate(zip(R_magnetic, Z_magnetic, A_magnetic, S_magnetic, name_magnetic)):
+                    ods[f'magnetics.b_field_pol_probe.{k}.name'] = name
+                    ods[f'magnetics.b_field_pol_probe.{k}.identifier'] = 'B_' + name
+                    ods[f'magnetics.b_field_pol_probe.{k}.position.r'] = r
+                    ods[f'magnetics.b_field_pol_probe.{k}.position.z'] = z
+                    ods[f'magnetics.b_field_pol_probe.{k}.length'] = s
+                    ods[f'magnetics.b_field_pol_probe.{k}.poloidal_angle'] = -a / 180 * np.pi
+                    ods[f'magnetics.b_field_pol_probe.{k}.toroidal_angle'] = 0.0 / 180 * np.pi
+                    ods[f'magnetics.b_field_pol_probe.{k}.type.index'] = 1
+                    ods[f'magnetics.b_field_pol_probe.{k}.turns'] = 1
+
+        return ods
+
 
 class OMFITdprobe(OMFITmhdin):
     @dynaLoad
@@ -859,13 +921,13 @@ class OMFITnstxMHD(SortedDict, OMFITascii):
     """
 
     def __init__(self, filename, use_leading_comma=None, **kw):
-        r'''
+        r"""
         OMFIT class to parse NSTX MHD device files
 
         :param filename: filename
 
         :param \**kw: arguments passed to __init__ of OMFITascii
-        '''
+        """
         OMFITascii.__init__(self, filename, **kw)
         SortedDict.__init__(self)
         self.dynaLoad = True
@@ -917,9 +979,9 @@ class OMFITnstxMHD(SortedDict, OMFITascii):
         return self
 
     def pretty_print(self):
-        '''
+        """
         Print data in file as arrays, as it is needed for a fortran namelist
-        '''
+        """
         for group in self:
             for item in self[group][0]:
                 print(f"{group.lower()}_{item.split('(')[0].lower()} = ", end='')
