@@ -290,14 +290,14 @@ class OMFITgoogleSheet(OMFITtree):
     https://docs.google.com/spreadsheets/d/1MJ8cFjFZ2pkt4OHWWIciWT3sM2hSADqzG78NDiqKgkU/edit?usp=sharing
 
     A sample call that should work to start up an OMFITgoogleSheet instance is:
-    >>> gsheet = OMFITgoogleSheet(
-    >>>     keyfile=os.sep.join([OMFITsrc, '..', 'samples', 'omfit-test-gsheet_key.json']),
-    >>>     sheet_name='OmfitDataSheetTestsheet',
-    >>>     subsheet_name='Sheet1',  # Default: lookup first subsheet
-    >>>     column_header_row_idx=5,  # Default: try to guess
-    >>>     units_row_idx=6,  # Default: None
-    >>>     data_start_row_idx=7,  # Default: header row + 1 (no units row) or + 2 (if units row specified)
-    >>> )
+    >> gsheet = OMFITgoogleSheet(
+    >>     keyfile=os.sep.join([OMFITsrc, '..', 'samples', 'omfit-test-gsheet_key.json']),
+    >>     sheet_name='OmfitDataSheetTestsheet',
+    >>     subsheet_name='Sheet1',  # Default: lookup first subsheet
+    >>     column_header_row_idx=5,  # Default: try to guess
+    >>     units_row_idx=6,  # Default: None
+    >>     data_start_row_idx=7,  # Default: header row + 1 (no units row) or + 2 (if units row specified)
+    >> )
     This call should connect to the example sheet. This is more than an example; this is a functional call
     that is read out of the docstring by the regression test and testing will fail if it doesn't work properly.
     """
@@ -826,14 +826,14 @@ class OMFITexperimentTable(OMFITgoogleSheet):
     https://docs.google.com/spreadsheets/d/1MJ8cFjFZ2pkt4OHWWIciWT3sM2hSADqzG78NDiqKgkU/edit?usp=sharing
 
     A sample call that should work to start up an OMFITgoogleSheet instance is:
-    >>> xtable = OMFITexperimentTable(
-    >>>     keyfile=os.sep.join([OMFITsrc, '..', 'samples', 'omfit-test-gsheet_key.json']),
-    >>>     sheet_name='OmfitDataSheetTestsheet',
-    >>>     subsheet_name='Sheet1',  # Default: lookup first subsheet
-    >>>     column_header_row_idx=5,  # Default: try to guess
-    >>>     units_row_idx=6,  # Default: search for units row
-    >>>     data_start_row_idx=7,  # Default: find first number after the header row in the shot column
-    >>> )
+    >> xtable = OMFITexperimentTable(
+    >>     keyfile=os.sep.join([OMFITsrc, '..', 'samples', 'omfit-test-gsheet_key.json']),
+    >>     sheet_name='OmfitDataSheetTestsheet',
+    >>     subsheet_name='Sheet1',  # Default: lookup first subsheet
+    >>     column_header_row_idx=5,  # Default: try to guess
+    >>     units_row_idx=6,  # Default: search for units row
+    >>     data_start_row_idx=7,  # Default: find first number after the header row in the shot column
+    >> )
     This call should connect to the example sheet. These data are used in regression tests and should be updated
     If the test sheet is changed.
     """
@@ -1129,15 +1129,15 @@ class OMFITexperimentTable(OMFITgoogleSheet):
         Gets MDSplus data for a list of signals, performs operations on specified time ranges, & saves results.
 
         This sample signal can be used as an instructional example or as an input for testing
-        >>> sample_signal_request = dict(
-        >>>     column_name='density',  # The sheet must have this column (happens to be a valid d3d ptname)
-        >>>     TDI=dict(EAST=r'\dfsdev'),  # d3d's TDI isn't listed b/c TDI defaults to column_name
-        >>>     treename=dict(EAST='PCS_EAST'),  # DIII-D isn't listed b/c default is None, which goes to PTDATA
-        >>>     factor={'DIII-D': 1e-13},  # This particular EAST pointname doesn't require a factor; defaults to 1
-        >>>     tfactor=dict(EAST=1e3),  # d3d times are already in ms
-        >>>     tmin='t min',  # str means read timing values from column w header exactly matching this string
-        >>>     tmax='t max',
-        >>> )
+        >> sample_signal_request = dict(
+        >>     column_name='density',  # The sheet must have this column (happens to be a valid d3d ptname)
+        >>     TDI=dict(EAST=r'\dfsdev'),  # d3d's TDI isn't listed b/c TDI defaults to column_name
+        >>     treename=dict(EAST='PCS_EAST'),  # DIII-D isn't listed b/c default is None, which goes to PTDATA
+        >>     factor={'DIII-D': 1e-13},  # This particular EAST pointname doesn't require a factor; defaults to 1
+        >>     tfactor=dict(EAST=1e3),  # d3d times are already in ms
+        >>     tmin='t min',  # str means read timing values from column w header exactly matching this string
+        >>     tmax='t max',
+        >> )
         This sample should work with the example/test sheet.
 
         If the sheet in question had ONLY DIII-D data, the same signal request could be accomplished via:
@@ -1242,13 +1242,13 @@ class OMFITexperimentTable(OMFITgoogleSheet):
         pointnames and some timing instructions.
 
         Here is a set of sample keywords that could be passed to this function:
-        >>> sample_kw = dict(
-        >>>     pointnames=['betan'],
-        >>>     tmin='t min',  # Can supply a constant float instead of a string
-        >>>     tmax='t max',
-        >>>     overwrite=True,
-        >>>     device_servers=dict(EAST='EAST_US'),  # Probably only needed for EAST
-        >>> )
+        >> sample_kw = dict(
+        >>     pointnames=['betan'],
+        >>     tmin='t min',  # Can supply a constant float instead of a string
+        >>     tmax='t max',
+        >>     overwrite=True,
+        >>     device_servers=dict(EAST='EAST_US'),  # Probably only needed for EAST
+        >> )
         These should work in xtable.write_efit_result where xtable is an
         OMFITexperimentTable instance connected to a google sheet that contains columns
         with headers 'betan', 't min', and 't max'
