@@ -39,6 +39,32 @@ except AttributeError:
 # hook up omfit and omas print streams
 omas.omas_utils._streams = _streams
 
+
+def tunnel_mds(server, treename):
+    '''
+    Resolve MDS+ server
+    NOTE: This function makes use of the optional `omfit_classes` dependency to establish a SSH tunnel to the MDS+ server.
+
+    :param server: MDS+ server address:port
+
+    :param treename: treename (in case treename affects server to be used)
+
+    :return: string with MDS+ server and port to be used
+    '''
+    try:
+        import omfit_classes.omfit_mds
+    except (ImportError, ModuleNotFoundError):
+        return server.format(**os.environ)
+    else:
+        server0 = omfit_classes.omfit_mds.translate_MDSserver(server, treename)
+        tunneled_server = omfit_classes.omfit_mds.tunneled_MDSserver(server0, quiet=False)
+        return tunneled_server
+
+    return server.format(**os.environ)
+
+
+omas.omas_machine.tunnel_mds = tunnel_mds
+
 # export __all__ from omas.__all__
 __all__ = list([x for x in ['omas'] + list(omas.__dict__.keys()) if not x.startswith('_')])
 
