@@ -716,7 +716,7 @@ class SortedDict(dict):
     """
 
     def __new__(cls, *args, **kwargs):
-        instance = super(SortedDict, cls).__new__(cls, *args, **kwargs)
+        instance = super().__new__(cls, *args, **kwargs)
         instance._OMFITkeyName = ''
         instance._OMFITparent = None
         instance.keyOrder = []
@@ -727,7 +727,7 @@ class SortedDict(dict):
         return instance
 
     def __init__(self, data=None, *args, **kwargs):
-        self.keyOrder = []
+        self.clear()
         self.caseInsensitive = kwargs.pop('caseInsensitive', False)
         self.sorted = kwargs.pop('sorted', False)
         self.limit = kwargs.pop('limit', 0)
@@ -755,6 +755,7 @@ class SortedDict(dict):
 
         # keep track of what classes have been loaded
         from omfit_classes.utils_base import _loaded_classes
+
         _loaded_classes.add(self.__class__.__name__)
 
     def __getattr__(self, attr):
@@ -806,7 +807,7 @@ class SortedDict(dict):
     @_docFromDict
     @dynaLoad
     def __len__(self):
-        return super(SortedDict, self).__len__()
+        return super().__len__()
 
     @_docFromDict
     @dynaLoad
@@ -832,7 +833,7 @@ class SortedDict(dict):
         elif self.caseInsensitive:
             self.keyOrder[self.index(key)] = key
 
-        super(SortedDict, self).__setitem__(key, self._setLocation(key, value))
+        super().__setitem__(key, self._setLocation(key, value))
 
         # make whatever SortedDict is under a caseInsensitive SortedDict, caseInsensitive itself
         if isinstance(self[key], SortedDict) and self.caseInsensitive:
@@ -841,7 +842,7 @@ class SortedDict(dict):
         # if limit>0 limit the number of entries
         while self.limit > 0 and len(self.keyOrder) > self.limit:
             delkey = self.keyOrder[0]
-            super(SortedDict, self).__delitem__(delkey)
+            super().__delitem__(delkey)
             self.keyOrder.remove(delkey)
 
     def _checkSetitem(self, key, value):
@@ -862,7 +863,7 @@ class SortedDict(dict):
     @dynaLoad
     def __delitem__(self, key):
         key = self._keyCaseInsensitive(key)
-        super(SortedDict, self).__delitem__(key)
+        super().__delitem__(key)
         self.keyOrder.remove(key)
 
     # does not need @dynaLoadKey, because functions that call _keyCaseInsensitive already do
@@ -882,19 +883,19 @@ class SortedDict(dict):
     def __getitem__(self, key):
         key = self._keyCaseInsensitive(key)
         try:
-            return super(SortedDict, self).__getitem__(key)
+            return super().__getitem__(key)
         except KeyError:
             # if this instance has a fetch method, then call it and try it __getitem__ again
             if hasattr(self, 'fetch'):
                 self.fetch()
-                return super(SortedDict, self).__getitem__(key)
+                return super().__getitem__(key)
             else:
                 raise
 
     @_docFromDict
     @dynaLoadKey
     def __contains__(self, key):
-        return super(SortedDict, self).__contains__(self._keyCaseInsensitive(key))
+        return super().__contains__(self._keyCaseInsensitive(key))
 
     def __getstate__(self):
         tmp = copy.copy(self.__dict__)
@@ -932,7 +933,7 @@ class SortedDict(dict):
     @dynaLoad
     def pop(self, key, *args):
         key = self._keyCaseInsensitive(key)
-        result = super(SortedDict, self).pop(key, *args)
+        result = super().pop(key, *args)
         try:
             self.keyOrder.remove(key)
         except ValueError:
@@ -943,7 +944,7 @@ class SortedDict(dict):
     @_docFromDict
     @dynaLoad
     def popitem(self):
-        result = super(SortedDict, self).popitem()
+        result = super().popitem()
         self.keyOrder.remove(result[0])
         return result
 
@@ -1059,7 +1060,7 @@ class SortedDict(dict):
 
     @_docFromDict
     def clear(self):
-        super(SortedDict, self).clear()
+        super().clear()
         self.keyOrder = []
 
     @dynaLoad
@@ -1529,7 +1530,7 @@ class OMFITdataset(object):
     within OMFIT
     """
 
-    def __init__(self, data_vars=None, coords=None, attrs=None,):
+    def __init__(self, data_vars=None, coords=None, attrs=None):
         r"""
         :param data_vars: see xarray.Dataset
 
